@@ -84,7 +84,7 @@
 #define KICONTHEMES_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KICONTHEMES_NO_DEPRECATED
-#  define KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
 #endif
 #ifdef KICONTHEMES_NO_DEPRECATED_WARNINGS
 #  define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE KICONTHEMES_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KICONTHEMES_DEPRECATED_WARNINGS_SINCE 0x57200
 #  endif
 #endif
 
